diff src/win_gaim.c @ 10210:4d3c2749deec

[gaim-migrate @ 11332] Now checking GAIMLANG and GAIMHOME instead of LANG and HOME env variables, to avoid conflicts with other apps that use them and to avoid HOME env variables intended for cygwin (using unix style path). Removed some obsolete code. committer: Tailor Script <tailor@pidgin.im>
author Herman Bloggs <hermanator12002@yahoo.com>
date Fri, 19 Nov 2004 20:39:09 +0000
parents b28f9be379b3
children 08251403c871
line wrap: on
line diff
--- a/src/win_gaim.c	Fri Nov 19 20:18:14 2004 +0000
+++ b/src/win_gaim.c	Fri Nov 19 20:39:09 2004 +0000
@@ -212,21 +212,20 @@
 }
 
 /* Determine and set Gaim locale as follows (in order of priority):
-   - Check LANG env var
+   - Check GAIMLANG env var
    - Check NSIS Installer Language reg value
    - Use default user locale
 */
 static void wgaim_set_locale() {
         char data[10];
         DWORD datalen = 10;
-	char* locale=NULL;
+        char* locale=NULL;
         char envstr[25];
         LCID lcid;
 
-        /* Check if user set LANG env var */
-        if((locale = (char*)getenv("LANG"))) {
+        /* Check if user set GAIMLANG env var */
+        if((locale = (char*)getenv("GAIMLANG")))
                 goto finish;
-        }
 
         if(read_reg_string(HKEY_CURRENT_USER, "SOFTWARE\\gaim", "Installer Language", (LPBYTE)&data, &datalen)) {
                 if((locale = wgaim_lcid_to_posix(atoi(data))))